@@ -2,9 +2,12 @@
 
 They live in the tox namespace and can be accessed as tox.[NAMESPACE.]NAME
 """
+import os
 import re
 import sys
 
+_THIS_FILE = os.path.realpath(os.path.abspath(__file__))
+
 
 def _construct_default_factors(cpython_versions, pypy_versions, other_interpreters):
     default_factors = {"py": sys.executable, "py2": "python2", "py3": "python3"}
@@ -43,6 +46,7 @@ class INFO:
     DEFAULT_CONFIG_NAME = "tox.ini"
     CONFIG_CANDIDATES = ("pyproject.toml", "tox.ini", "setup.cfg")
     IS_WIN = sys.platform == "win32"
+    IS_PYPY = hasattr(sys, "pypy_version_info")
 
 
 class PIP:
@@ -75,3 +79,12 @@ class PIP:
     ]
     INSTALL_SHORT_OPTIONS_ARGUMENT = ["-{}".format(option) for option in SHORT_OPTIONS]
     INSTALL_LONG_OPTIONS_ARGUMENT = ["--{}".format(option) for option in LONG_OPTIONS]
+
+
+_HELP_DIR = os.path.join(os.path.dirname(_THIS_FILE), "helper")
+VERSION_QUERY_SCRIPT = os.path.join(_HELP_DIR, "get_version.py")
+SITE_PACKAGE_QUERY_SCRIPT = os.path.join(_HELP_DIR, "get_site_package_dir.py")
+BUILD_REQUIRE_SCRIPT = os.path.join(_HELP_DIR, "build_requires.py")
+BUILD_ISOLATED = os.path.join(_HELP_DIR, "build_isolated.py")
+PARALLEL_RESULT_JSON_PREFIX = ".tox-result"
+PARALLEL_RESULT_JSON_SUFFIX = ".json"
