@@ -4,7 +4,7 @@ import py
 import pytest
 
 from tox.package.builder.isolated import get_build_info
-from tox.session import Reporter
+from tox.reporter import _INSTANCE
 
 
 def test_verbose_isolated_build(initproj, mock_venv, cmd):
@@ -22,7 +22,7 @@ def test_verbose_isolated_build(initproj, mock_venv, cmd):
                                 """,
         },
     )
-    result = cmd("--sdistonly", "-vvv")
+    result = cmd("--sdistonly", "-v", "-v", "-v", "-e", "py")
     assert "running sdist" in result.out, result.out
     assert "running egg_info" in result.out, result.out
     assert "Writing example123-0.5{}setup.cfg".format(os.sep) in result.out, result.out
@@ -44,13 +44,13 @@ def test_dist_exists_version_change(mock_venv, initproj, cmd):
         },
     )
     result = cmd("-e", "py")
-    assert result.ret == 0, result.out
+    result.assert_success()
 
     new_code = base.join("setup.py").read_text("utf-8").replace("0.1", "0.2")
     base.join("setup.py").write_text(new_code, "utf-8")
 
     result = cmd("-e", "py")
-    assert result.ret == 0, result.out
+    result.assert_success()
 
 
 def test_package_isolated_no_pyproject_toml(initproj, cmd):
@@ -63,8 +63,8 @@ def test_package_isolated_no_pyproject_toml(initproj, cmd):
             """
         },
     )
-    result = cmd("--sdistonly")
-    assert result.ret == 1
+    result = cmd("--sdistonly", "-e", "py")
+    result.assert_fail()
     assert result.outlines == ["ERROR: missing {}".format(py.path.local().join("pyproject.toml"))]
 
 
@@ -79,20 +79,19 @@ def toml_file_check(initproj, version, message, toml):
             "pyproject.toml": toml,
         },
     )
-    reporter = Reporter(None)
 
-    with pytest.raises(SystemExit, message=1):
-        get_build_info(py.path.local(), reporter)
+    with pytest.raises(SystemExit, match="1"):
+        get_build_info(py.path.local())
     toml_file = py.path.local().join("pyproject.toml")
     msg = "ERROR: {} inside {}".format(message, toml_file)
-    assert reporter.reported_lines == [msg]
+    assert _INSTANCE.messages == [msg]
 
 
-def test_package_isolated_toml_no_build_system(initproj, cmd):
+def test_package_isolated_toml_no_build_system(initproj):
     toml_file_check(initproj, 1, "build-system section missing", "")
 
 
-def test_package_isolated_toml_no_requires(initproj, cmd):
+def test_package_isolated_toml_no_requires(initproj):
     toml_file_check(
         initproj,
         2,
@@ -103,7 +102,7 @@ def test_package_isolated_toml_no_requires(initproj, cmd):
     )
 
 
-def test_package_isolated_toml_no_backend(initproj, cmd):
+def test_package_isolated_toml_no_backend(initproj):
     toml_file_check(
         initproj,
         3,
@@ -115,7 +114,7 @@ def test_package_isolated_toml_no_backend(initproj, cmd):
     )
 
 
-def test_package_isolated_toml_bad_requires(initproj, cmd):
+def test_package_isolated_toml_bad_requires(initproj):
     toml_file_check(
         initproj,
         4,
@@ -128,7 +127,7 @@ def test_package_isolated_toml_bad_requires(initproj, cmd):
     )
 
 
-def test_package_isolated_toml_bad_backend(initproj, cmd):
+def test_package_isolated_toml_bad_backend(initproj):
     toml_file_check(
         initproj,
         5,
