@@ -115,6 +115,32 @@ def test_envdir_equals_toxini_errors_out(cmd, initproj):
     result.assert_fail()
 
 
+def test_envdir_would_delete_some_directory(cmd, initproj):
+    projdir = initproj(
+        "example-123",
+        filedefs={
+            "tox.ini": """\
+                [tox]
+
+                [testenv:venv]
+                envdir=example
+                commands=
+            """
+        },
+    )
+
+    result = cmd("-e", "venv")
+    assert projdir.join("example/__init__.py").exists()
+    result.assert_fail()
+    assert "cowardly refusing to delete `envdir`" in result.out
+
+
+def test_recreate(cmd, initproj):
+    initproj("example-123", filedefs={"tox.ini": ""})
+    cmd("-e", "py", "--notest").assert_success()
+    cmd("-r", "-e", "py", "--notest").assert_success()
+
+
 def test_run_custom_install_command_error(cmd, initproj):
     initproj(
         "interp123-0.5",
@@ -789,6 +815,73 @@ def test_notest_setup_py_error(initproj, cmd):
     assert re.search("ERROR:.*InvocationError", result.out)
 
 
+def test_devenv(initproj, cmd):
+    initproj(
+        "example123",
+        filedefs={
+            "setup.py": """\
+                from setuptools import setup
+                setup(name='x')
+            """,
+            "tox.ini": """\
+            [tox]
+            # envlist is ignored for --devenv
+            envlist = foo,bar,baz
+
+            [testenv]
+            # --devenv implies --notest
+            commands = python -c "exit(1)"
+            """,
+        },
+    )
+    result = cmd("--devenv", "venv")
+    result.assert_success()
+    # `--devenv` defaults to the `py` environment and a develop install
+    assert "py develop-inst:" in result.out
+    assert re.search("py create:.*venv", result.out)
+
+
+def test_devenv_does_not_allow_multiple_environments(initproj, cmd):
+    initproj(
+        "example123",
+        filedefs={
+            "setup.py": """\
+                from setuptools import setup
+                setup(name='x')
+            """,
+            "tox.ini": """\
+            [tox]
+            envlist=foo,bar,baz
+            """,
+        },
+    )
+
+    result = cmd("--devenv", "venv", "-e", "foo,bar")
+    result.assert_fail()
+    assert result.err == "ERROR: --devenv requires only a single -e\n"
+
+
+def test_devenv_does_not_delete_project(initproj, cmd):
+    initproj(
+        "example123",
+        filedefs={
+            "setup.py": """\
+                from setuptools import setup
+                setup(name='x')
+            """,
+            "tox.ini": """\
+            [tox]
+            envlist=foo,bar,baz
+            """,
+        },
+    )
+
+    result = cmd("--devenv", "")
+    result.assert_fail()
+    assert "would delete project" in result.out
+    assert "ERROR: ConfigError: envdir must not equal toxinidir" in result.out
+
+
 def test_PYC(initproj, cmd, monkeypatch):
     initproj("example123", filedefs={"tox.ini": ""})
     monkeypatch.setenv("PYTHONDOWNWRITEBYTECODE", "1")
